// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIPI_VERSION_H
#define KIPI_VERSION_H

#define KIPI_VERSION_STRING "5.2.0"
#define KIPI_VERSION_MAJOR 5
#define KIPI_VERSION_MINOR 2
#define KIPI_VERSION_PATCH 0
#define KIPI_VERSION ((5<<16)|(2<<8)|(0))

#endif
